User: ko5tik
Date: 02/02/22 10:28:09
Modified: src/java/xtags OptionSet.java Tag.java TagFamily.java
TagParameter.java
Log:
weed out all references to Documented. only one compile error
on XJavaDoc instantiation.
Aslak, would you please fix it?
I go home and prepare myself to watching USA-Russia
Revision Changes Path
1.2 +101 -101 xdocletgui/src/java/xtags/OptionSet.java
Index: OptionSet.java
===================================================================
RCS file: /cvsroot/xdoclet/xdocletgui/src/java/xtags/OptionSet.java,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -w -r1.1 -r1.2
--- OptionSet.java 25 Jan 2002 00:50:19 -0000 1.1
+++ OptionSet.java 22 Feb 2002 18:28:09 -0000 1.2
@@ -35,7 +35,7 @@
*/
package xtags;
-import xjavadoc.Documented;
+import xjavadoc.XProgramElement;
import xtags.condition.Condition;
/**
@@ -84,15 +84,15 @@
/**
* Describe what the method does
*
* @param documented Describe what the parameter does
* @return Describe the return value
* @todo-javadoc Write javadocs for return value
* @todo-javadoc Write javadocs for method
* @todo-javadoc Write javadocs for method parameter
*/
- public boolean eval(Documented documented) {
+ public boolean eval(XProgramElement xprogramelement) {
if (_condition != null) {
- return _condition.eval(documented);
+ return _condition.eval(xprogramelement);
}
else {
return true;
@@ -84,15 +84,15 @@
* Describe what the method does
*
- * @param documented Describe what the parameter does
+ * @param xprogramelement Describe what the parameter does
* @return Describe the return value
* @todo-javadoc Write javadocs for return value
1.2 +175 -174 xdocletgui/src/java/xtags/Tag.java
Index: Tag.java
===================================================================
RCS file: /cvsroot/xdoclet/xdocletgui/src/java/xtags/Tag.java,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -w -r1.1 -r1.2
--- Tag.java 25 Jan 2002 00:50:19 -0000 1.1
+++ Tag.java 22 Feb 2002 18:28:09 -0000 1.2
@@ -37,7 +37,7 @@
import java.util.List;
import java.util.ArrayList;
-import xjavadoc.Documented;
+import xjavadoc.XProgramElement;
import xtags.condition.Or;
import xtags.condition.Condition;
@@ -128,13 +128,14 @@
/**
* @todo this method should be defined in an interface
* @param documented Describe what the parameter does
* @return Describe the return value
* @todo-javadoc Write javadocs for method parameter
+ * @todo-javadoc Write javadocs for method parameter
* @todo-javadoc Write javadocs for return value
*/
- public boolean supports(Documented documented) {
- return _or.eval(documented);
+ public boolean supports(XProgramElement xprogramelement) {
+ return _or.eval(xprogramelement);
}
1.2 +175 -175 xdocletgui/src/java/xtags/TagFamily.java
@@ -128,13 +128,14 @@
/**
* @todo this method should be defined in an interface
- * @param documented Describe what the parameter does
+ * @param xprogramelement Describe what the parameter does
* @return Describe the return value
* @todo-javadoc Write javadocs for method parameter
Index: TagFamily.java
===================================================================
RCS file: /cvsroot/xdoclet/xdocletgui/src/java/xtags/TagFamily.java,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -w -r1.1 -r1.2
--- TagFamily.java 25 Jan 2002 00:50:20 -0000 1.1
+++ TagFamily.java 22 Feb 2002 18:28:09 -0000 1.2
@@ -38,9 +38,8 @@
import java.util.ArrayList;
import java.util.List;
import java.util.Collections;
-import xjavadoc.Documented;
import xtags.condition.Or;
-
+import xjavadoc.XProgramElement;
/**
* This class represents a family of tags, such as ejb, struts, weblogic, jboss
* etc.
@@ -141,13 +140,14 @@
/**
* @todo we should ask our constraint whether we support the documented. I
* don't remember why we need a Condition class now. Do we?
* @param documented Describe what the parameter does
* @return Describe the return value
* @todo-javadoc Write javadocs for method parameter
+ * @todo-javadoc Write javadocs for method parameter
* @todo-javadoc Write javadocs for return value
*/
- public boolean supports(Documented documented) {
- return _or.eval(documented);
+ public boolean supports(XProgramElement xprogramelement) {
+ return _or.eval(xprogramelement);
}
1.2 +263 -261 xdocletgui/src/java/xtags/TagParameter.java
@@ -141,13 +140,14 @@
* @todo we should ask our constraint whether we support the documented. I
* don't remember why we need a Condition class now. Do we?
- * @param documented Describe what the parameter does
+ * @param xprogramelement Describe what the parameter does
* @return Describe the return value
* @todo-javadoc Write javadocs for method parameter
Index: TagParameter.java
===================================================================
RCS file: /cvsroot/xdoclet/xdocletgui/src/java/xtags/TagParameter.java,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -w -r1.1 -r1.2
--- TagParameter.java 25 Jan 2002 00:50:20 -0000 1.1
+++ TagParameter.java 22 Feb 2002 18:28:09 -0000 1.2
@@ -41,7 +41,7 @@
import java.util.Properties;
import xjavadoc.XClass;
-import xjavadoc.Documented;
+import xjavadoc.XProgramElement;
import xtags.condition.Condition;
import xtags.condition.Or;
import xtags.condition.And;
@@ -176,18 +176,19 @@
/**
* Gets the valid options for the given Documented, or null if
*
- * @param documented the options for the documented.
+ * @param xprogramelement Describe what the parameter does
* @return The Options value
+ * @todo-javadoc Write javadocs for method parameter
*/
- public String[] getOptions(Documented documented) {
+ public String[] getOptions(XProgramElement xprogramelement) {
if (hasOptions()) {
for (int i = 0; i < _optionSets.size(); i++) {
OptionSet optionSet = (OptionSet)_optionSets.get(i);
- if (optionSet.eval(documented)) {
+ if (optionSet.eval(xprogramelement)) {
return optionSet.getOptions();
}
}
- throw new IllegalStateException("There are options, but none
apply to " + documented.toString());
+ throw new IllegalStateException("There are options, but none
apply to " + xprogramelement.toString());
}
else {
return null;
@@ -211,15 +212,16 @@
/**
* Describe what the method does
*
* @param documented Describe what the parameter does
* @return Describe the return value
+ * @todo-javadoc Write javadocs for method parameter
* @todo-javadoc Write javadocs for method
* @todo-javadoc Write javadocs for method parameter
* @todo-javadoc Write javadocs for return value
*/
- public boolean supports(Documented documented) {
+ public boolean supports(XProgramElement xprogramelement) {
if (_condition != null) {
- return _condition.eval(documented);
+ return _condition.eval(xprogramelement);
}
else {
return true;
@@ -211,15 +212,16 @@
* Describe what the method does
*
- * @param documented Describe what the parameter does
+ * @param xprogramelement Describe what the parameter does
* @return Describe the return value
_______________________________________________
Xdoclet-devel mailing list
[EMAIL PROTECTED]
https://lists.sourceforge.net/lists/listinfo/xdoclet-devel